@@ -668,6 +668,7 @@
 #define PCI_CHIP_VERDE_6829 0x6829
 #define PCI_CHIP_VERDE_682A 0x682A
 #define PCI_CHIP_VERDE_682B 0x682B
+#define PCI_CHIP_VERDE_682C 0x682C
 #define PCI_CHIP_VERDE_682D 0x682D
 #define PCI_CHIP_VERDE_682F 0x682F
 #define PCI_CHIP_VERDE_6830 0x6830
@@ -683,11 +684,15 @@
 #define PCI_CHIP_OLAND_6601 0x6601
 #define PCI_CHIP_OLAND_6602 0x6602
 #define PCI_CHIP_OLAND_6603 0x6603
+#define PCI_CHIP_OLAND_6604 0x6604
+#define PCI_CHIP_OLAND_6605 0x6605
 #define PCI_CHIP_OLAND_6606 0x6606
 #define PCI_CHIP_OLAND_6607 0x6607
+#define PCI_CHIP_OLAND_6608 0x6608
 #define PCI_CHIP_OLAND_6610 0x6610
 #define PCI_CHIP_OLAND_6611 0x6611
 #define PCI_CHIP_OLAND_6613 0x6613
+#define PCI_CHIP_OLAND_6617 0x6617
 #define PCI_CHIP_OLAND_6620 0x6620
 #define PCI_CHIP_OLAND_6621 0x6621
 #define PCI_CHIP_OLAND_6623 0x6623
@@ -700,12 +705,15 @@
 #define PCI_CHIP_HAINAN_666F 0x666F
 #define PCI_CHIP_BONAIRE_6640 0x6640
 #define PCI_CHIP_BONAIRE_6641 0x6641
+#define PCI_CHIP_BONAIRE_6646 0x6646
+#define PCI_CHIP_BONAIRE_6647 0x6647
 #define PCI_CHIP_BONAIRE_6649 0x6649
 #define PCI_CHIP_BONAIRE_6650 0x6650
 #define PCI_CHIP_BONAIRE_6651 0x6651
 #define PCI_CHIP_BONAIRE_6658 0x6658
 #define PCI_CHIP_BONAIRE_665C 0x665C
 #define PCI_CHIP_BONAIRE_665D 0x665D
+#define PCI_CHIP_BONAIRE_665F 0x665F
 #define PCI_CHIP_KABINI_9830 0x9830
 #define PCI_CHIP_KABINI_9831 0x9831
 #define PCI_CHIP_KABINI_9832 0x9832
@@ -722,6 +730,22 @@
 #define PCI_CHIP_KABINI_983D 0x983D
 #define PCI_CHIP_KABINI_983E 0x983E
 #define PCI_CHIP_KABINI_983F 0x983F
+#define PCI_CHIP_MULLINS_9850 0x9850
+#define PCI_CHIP_MULLINS_9851 0x9851
+#define PCI_CHIP_MULLINS_9852 0x9852
+#define PCI_CHIP_MULLINS_9853 0x9853
+#define PCI_CHIP_MULLINS_9854 0x9854
+#define PCI_CHIP_MULLINS_9855 0x9855
+#define PCI_CHIP_MULLINS_9856 0x9856
+#define PCI_CHIP_MULLINS_9857 0x9857
+#define PCI_CHIP_MULLINS_9858 0x9858
+#define PCI_CHIP_MULLINS_9859 0x9859
+#define PCI_CHIP_MULLINS_985A 0x985A
+#define PCI_CHIP_MULLINS_985B 0x985B
+#define PCI_CHIP_MULLINS_985C 0x985C
+#define PCI_CHIP_MULLINS_985D 0x985D
+#define PCI_CHIP_MULLINS_985E 0x985E
+#define PCI_CHIP_MULLINS_985F 0x985F
 #define PCI_CHIP_KAVERI_1304 0x1304
 #define PCI_CHIP_KAVERI_1305 0x1305
 #define PCI_CHIP_KAVERI_1306 0x1306
@@ -740,6 +764,7 @@
 #define PCI_CHIP_KAVERI_1315 0x1315
 #define PCI_CHIP_KAVERI_1316 0x1316
 #define PCI_CHIP_KAVERI_1317 0x1317
+#define PCI_CHIP_KAVERI_1318 0x1318
 #define PCI_CHIP_KAVERI_131B 0x131B
 #define PCI_CHIP_KAVERI_131C 0x131C
 #define PCI_CHIP_KAVERI_131D 0x131D
